==> apache-tsfile-2.0.2-source-release.zip: apache-tsfile-2.0.2/java/tsfile/src/main/java/org/apache/tsfile/file/metadata/ColumnSchemaBuilder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.tsfile.file.metadata;

import org.apache.tsfile.annotations.TsFileApi;
import org.apache.tsfile.enums.TSDataType;
import org.apache.tsfile.write.record.Tablet.ColumnCategory;

public class ColumnSchemaBuilder {

  private String columnName;
  private TSDataType columnDataType;
  private ColumnCategory columnCategory = ColumnCategory.FIELD;

  @TsFileApi
  public ColumnSchema build() {
    validateParameters();
    return new ColumnSchema(columnName, columnDataType, columnCategory);
  }

  @TsFileApi
  public ColumnSchemaBuilder name(String columnName) {
    if (columnName == null || columnName.isEmpty()) {
      throw new IllegalArgumentException("Column name must be a non empty string");
    }
    this.columnName = columnName;
    return this;
  }

  @TsFileApi
  public ColumnSchemaBuilder dataType(TSDataType columnType) {
    this.columnDataType = columnType;
    return this;
  }

  @TsFileApi
  public ColumnSchemaBuilder category(ColumnCategory columnCategory) {
    this.columnCategory = columnCategory;
    return this;
  }

  private void validateParameters() {
    if (columnName == null) {
      throw new IllegalStateException("Column name must be set before building");
    }
    if (columnDataType == null) {
      throw new IllegalStateException("Column data type must be set before building");
    }
  }
}

==> apache-tsfile-2.1.1-source-release.zip: apache-tsfile-2.1.1/java/tsfile/src/main/java/org/apache/tsfile/file/metadata/ColumnSchemaBuilder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.tsfile.file.metadata;

import org.apache.tsfile.annotations.TsFileApi;
import org.apache.tsfile.enums.ColumnCategory;
import org.apache.tsfile.enums.TSDataType;

public class ColumnSchemaBuilder {

  private String columnName;
  private TSDataType columnDataType;
  private ColumnCategory columnCategory = ColumnCategory.FIELD;

  @TsFileApi
  public ColumnSchema build() {
    validateParameters();
    return new ColumnSchema(columnName, columnDataType, columnCategory);
  }

  @TsFileApi
  public ColumnSchemaBuilder name(String columnName) {
    if (columnName == null || columnName.isEmpty()) {
      throw new IllegalArgumentException("Column name must be a non empty string");
    }
    this.columnName = columnName;
    return this;
  }

  @TsFileApi
  public ColumnSchemaBuilder dataType(TSDataType columnType) {
    this.columnDataType = columnType;
    return this;
  }

  @TsFileApi
  public ColumnSchemaBuilder category(ColumnCategory columnCategory) {
    this.columnCategory = columnCategory;
    return this;
  }

  private void validateParameters() {
    if (columnName == null) {
      throw new IllegalStateException("Column name must be set before building");
    }
    if (columnDataType == null) {
      throw new IllegalStateException("Column data type must be set before building");
    }
  }
}
